@@ -12,7 +12,7 @@ mice.impute.pmm5 <- function (y, ry, x, donors=3 , noise = 10^5 ,
     # add some small noise to create unique entries in matrix d0
     d00 <- abs(diff(dfr[,"yhat"]))
     fg1 <- min( d00[ d00 > 0 ] )    
-    dfr[,"yhat"] <- dfr[,"yhat"] + runif( nrow(dfr) , 0 , fg1 / noise )
+    dfr[,"yhat"] <- dfr[,"yhat"] + stats::runif( nrow(dfr) , 0 , fg1 / noise )
     dfr <- data.frame(dfr[ order(dfr[,3] ) , ])             
     dfr$sortindex <- seq( 1 , nrow(dfr))
 	dfr$obsindex_low <- cumsum( dfr$obs )
@@ -22,8 +22,8 @@ mice.impute.pmm5 <- function (y, ry, x, donors=3 , noise = 10^5 ,
     c1 <- Ny - cumsum( dfr$obs[ ind ] )   + 1    
 #    dfr$obsindex_upp <- c1[ ind ]
     dfr$obsindex_upp <- c1[ ind ]	
-	dfr$obsindex_low <- squeeze( dfr$obsindex_low , c(1,Ny)) 
-	dfr$obsindex_upp <- squeeze( dfr$obsindex_upp , c(1,Ny)) 	
+	dfr$obsindex_low <- mice::squeeze( dfr$obsindex_low , c(1,Ny)) 
+	dfr$obsindex_upp <- mice::squeeze( dfr$obsindex_upp , c(1,Ny)) 	
 #    dfr[ dfr$obsindex_low < 1  , "obsindex_low" ] <- 1
 #    dfr[ dfr$obsindex_upp > Ny  , "obsindex_upp" ] <- Ny
     dfr0 <- dfr[ dfr$obs == 0 , ]
@@ -34,8 +34,8 @@ mice.impute.pmm5 <- function (y, ry, x, donors=3 , noise = 10^5 ,
 
 	dfr0 <- dfr0[ order(dfr0$index_obs_miss) , ]
     for ( dd in 1:donors){
-        ydonors[,dd] <- dfr1[ squeeze( dfr0$obsindex_low - dd + 1 ,c(1,Ny) ) , "y"]
-        ydonors[,dd+donors] <- dfr1[ squeeze( dfr0$obsindex_upp + dd - 1 ,c(1,Ny) ) , "y"]    
+        ydonors[,dd] <- dfr1[ mice::squeeze( dfr0$obsindex_low - dd + 1 ,c(1,Ny) ) , "y"]
+        ydonors[,dd+donors] <- dfr1[ mice::squeeze( dfr0$obsindex_upp + dd - 1 ,c(1,Ny) ) , "y"]    
                         }
     ind.sample <- sample( 1:(2*donors) , N0 , replace = TRUE )
     imp <- ydonors[ cbind( 1:N0 , ind.sample) ]
