@@ -1,4 +1,5 @@
-mids2mlwin <- function(imp, file.prefix, path = getwd(), sep = " ", dec = ".", silent = FALSE)
+mids2mlwin <- function(imp, file.prefix, path = getwd(), sep = " ", dec = ".", silent = FALSE,
+  X = NULL )
 {
   m <- imp$m
   i <- imp$iteration
@@ -6,11 +7,15 @@ mids2mlwin <- function(imp, file.prefix, path = getwd(), sep = " ", dec = ".", s
   varnames <- names(imp$imp)[!sapply(imp$imp, is.null)]
   impnames <- paste0(file.prefix, seq(1, m, 1), ".txt")
   f1 <- paste0( file.prefix , "__impvals.txt" ) 
-  write(x = varnames, file = f1 , append = F, ncolumns = length(varnames), sep = " ")
-  write(x = c(n, m),  file = f1 , append = T, ncolumns = 1)
-  write(x = impnames, file = f1 , append = T, ncolumns = m, sep = "\t")
+  base::write(x = varnames, file = f1 , append = F, ncolumns = length(varnames), sep = " ")
+  base::write(x = c(n, m),  file = f1 , append = T, ncolumns = 1)
+  base::write(x = impnames, file = f1 , append = T, ncolumns = m, sep = "\t")
   for (k in 1:m){
-    write.table(x = complete(imp, k), file = impnames[k], dec = dec, sep = sep, 
+    h1 <- mice::complete(imp, k)
+	if ( ! is.null(X) ){
+		h1 <- data.frame(  X , h1	)										
+	  				   }	
+    utils::write.table(x = h1 , file = impnames[k], dec = dec, sep = sep, 
                 col.names = F, row.names = F, quote = F, eol = "\n", )
   }
   if (!silent){
