@@ -9,7 +9,7 @@ save.data <- function( data , filename , type="Rdata" , path=getwd() ,
 	dir <- path
 	file <- filename	
 	if ( ! is.null(suffix) ){
-		file <- paste0( file , suffix_space , suffix )
+		file <- base::paste0( file , suffix_space , suffix )
 							}
 	#*** add index in data frame if requested
 	if ( index){ 
@@ -38,31 +38,31 @@ save.data <- function( data , filename , type="Rdata" , path=getwd() ,
     #*** Rdata objects	
 	if ( "Rdata" %in% type  ){
 	    file <- calc_filename( file=file0 , type="Rdata")
-		base::save( data , file= file.path( dir , file ) )
+		base::save( data , file= base::file.path( dir , file ) )
 				}
     #*** csv2 objects
 	if ("csv2" %in% type  ){
 	    if ( is.null(na)){ na <- "" }
 		file <- calc_filename( file=file0 , type="csv2")
-		utils::write.csv2( data , file.path(dir,file) , row.names=row.names , na=na ,... )
+		utils::write.csv2( data , base::file.path(dir,file) , row.names=row.names , na=na ,... )
 				}
     #*** csv objects
 	if ("csv" %in% type ){
 	    if ( is.null(na)){ na <- "" }
 		file <- calc_filename( file=file0 , type="csv")
-		utils::write.csv( data , file.path(dir,file) , row.names=row.names , na=na,  ... )
+		utils::write.csv( data , base::file.path(dir,file) , row.names=row.names , na=na,  ... )
 				}
     #*** table objects
 	if ("table" %in% type ){
 	    if ( is.null(na)){ na <- "." }
 		file <- calc_filename( file=file0 , type="table")
-		utils::write.table( data , file.path(dir,file) , na=na , row.names=row.names , ... )
+		utils::write.table( data , base::file.path(dir,file) , na=na , row.names=row.names , ... )
 				}
     #*** sav objects (SPSS objects)
 	if ( "sav" %in% type ){
 	    file <- calc_filename( file=file0 , type="sav")
-		data <- sjmisc::set_label( data, lab=attr(data, "variable.labels") )
-		sjmisc::write_spss( data , file.path( dir , file ) )		
+		data <- sjmisc::set_label( data, lab= base::attr(data, "variable.labels") )
+		sjmisc::write_spss( data , base::file.path( dir , file ) )		
 				}				
 			}
 #########################################################################			
@@ -74,11 +74,11 @@ calc_filename <- function( file , type){
 	if ( type == "table" ){ 
 			type2 <- "dat" 
 				}
-	i1 <- grep( type2 , file )
-	i1 <- grep( paste0("\\.",type2) , file , fixed=TRUE)	
-	if ( length(i1) == 0 ){
-		file <- paste0( file , "." , type2 )
+	i1 <- base::grep( type2 , file )
+	i1 <- base::grep( paste0("\\.",type2) , file , fixed=TRUE)	
+	if ( base::length(i1) == 0 ){
+		file <- base::paste0( file , "." , type2 )
 						}
-	return(file)
+	base::return(file)
 		}
 ########################################################		
\ No newline at end of file
